@@ -1,28 +1,23 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# Copyright (c) Mito.
-# Distributed under the terms of the Modified BSD License.
-
+# Copyright (c) Saga Inc.
+# Distributed under the terms of the GPL License.
 """
 Changes a specific field in the user.json file
 """
 
-from typing import TYPE_CHECKING, Any
+from typing import Any
 from mitosheet.mito_analytics import identify
+from mitosheet.types import StepsManagerType
 from mitosheet.user import set_user_field
 
-if TYPE_CHECKING:
-    from mitosheet.steps_manager import StepsManager
-else:
-    StepsManager = Any
-
 
 SET_USER_FIELD_EVENT = 'set_user_field_update'
 SET_USER_FIELD_PARAMS = ['field', 'value']
 
 
-def execute_set_user_field_update(steps_manager: StepsManager, field: str, value: Any) -> None:
+def execute_set_user_field_update(steps_manager: StepsManagerType, field: str, value: Any) -> None:
     """
     The function responsible for setting specific field values
     for the user.json file, and then reidentifying the user
